

=================
API documentation
=================


Datamesh
---------------------
.. currentmodule:: oceanum.datamesh


End-user classes

.. autosummary::
   :toctree: classes/datamesh

    Connector
    Datasource
    Catalog
    Query

Storage
---------------------
.. currentmodule:: oceanum.storage


End-user classes

.. autosummary::
   :toctree: classes/storage

    FileSystem

.. Internal classes

.. .. autosummary::
..    :toctree: classes/datamesh

.. 
    automodule:: oceanum.datamesh.connection
    :members:

.. 
    automodule:: oceanum.datamesh.datasource
    :members:

.. 
    automodule:: oceanum.datamesh.catalog
    :members:

.. 
    automodule:: oceanum.datamesh.query
    :members:
    :undoc-members:



   